CachedImageBuilder class

Cached image widget.

キャッシュされた画像を表示するためのウィジェット。

Inheritance
Annotations

Constructors

CachedImageBuilder({required Key? key, required Widget builder(BuildContext context), double? width, double? height, bool showLoadingIndicator = false, Color? coverBackgroundColor})
Cached image widget.
const

Properties

builder → Widget Function(BuildContext context)
Builder that returns the widget to be converted to an image.
final
coverBackgroundColor → Color?
Cover background color (optional).
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Image height (optional).
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLoadingIndicator → bool
Show loading indicator while caching (optional).
final
width → double?
Image width (optional).
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CachedImageBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited